@@ -20,7 +20,6 @@
 #' bs_get_notification_count()
 bs_get_notification_count <- function(user = get_bluesky_user(), pass = get_bluesky_pass(),
                                       auth = bs_auth(user, pass), clean = TRUE) {
-
   req <- httr2::request('https://bsky.social/xrpc/app.bsky.notification.getUnreadCount') |>
     httr2::req_auth_bearer_token(token = auth$accessJwt)
 
@@ -28,7 +27,9 @@ bs_get_notification_count <- function(user = get_bluesky_user(), pass = get_blue
     httr2::req_perform() |>
     httr2::resp_body_json()
 
-  if (!clean) return(resp)
+  if (!clean) {
+    return(resp)
+  }
 
   resp |>
     tibble::as_tibble()
