@@ -23,7 +23,6 @@
 bs_get_notifications <- function(cursor = NULL, limit = NULL,
                                  user = get_bluesky_user(), pass = get_bluesky_pass(),
                                  auth = bs_auth(user, pass), clean = TRUE) {
-
   if (!is.null(limit)) {
     if (!is.numeric(limit)) {
       cli::cli_abort('{.arg limit} must be numeric.')
@@ -43,7 +42,9 @@ bs_get_notifications <- function(cursor = NULL, limit = NULL,
 
   resp <- repeat_request(req, req_seq, cursor, txt = 'Fetching notifications')
 
-  if (!clean) return(resp)
+  if (!clean) {
+    return(resp)
+  }
 
   resp |>
     lapply(process_notifications) |>
